@@ -135,7 +135,7 @@ class Data:
         self.q_shape = 'linear'
 
 class Foreperson:
-    def __init__(self, run_numbers, yaml_file, title):
+    def __init__(self, run_numbers, yaml_file, directory, title):
         self.creator = Creator()
         self.data_source = DataSource(title)
         self.reduction = Reduction()
@@ -258,7 +258,7 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', title='Unkno
         file, pass this as a :py:attr:`dict`.
     title (:py:attr:`str`): A title for the experiment.
     """
-    the_boss = Foreperson(run_numbers, yaml_file, title)
+    the_boss = Foreperson(run_numbers, yaml_file, directory, title)
 
     files_to_reduce = the_boss.reduction.input_files
 
